<?php
/**
 * @package      ITPrism Components
 * @subpackage   ITPMeta
 * @author       Todor Iliev
 * @copyright    Copyright (C) 2010 Todor Iliev <todor@itprism.com>. All rights reserved.
 * @license      http://www.gnu.org/copyleft/gpl.html GNU/GPL
 * ITPMeta is free software. This version may have been modified pursuant
 * to the GNU General Public License, and as distributed it includes or
 * is derivative of works licensed under the GNU General Public License or
 * other free or open source software licenses.
 */

// Check to ensure this file is included in Joomla!
defined('_JEXEC') or die();

jimport('joomla.error.log');
jimport('joomla.application.component.controller');

/**
 * ITPMeta Users Controller
 *
 * @package     ITPrism Components
 * @subpackage  ITPMeta
 */
class UrlsControllerItpMeta extends JController {
    
    // Check the table in so it can be edited.... we are done with it anyway
    private $defaultLink = 'index.php?option=com_itpmeta&controller=urls&view=urls';
    
    public function __construct($config = array()){
        parent::__construct($config);
        
        //       Register Extra tasks
        $this->registerTask('add', 'display');
        $this->registerTask('edit', 'display');
        $this->registerTask('apply', 'save');
    
    }
    
    public function display(){
        
        $document = & JFactory::getDocument();
        /* @var $document JDocument */
        
        // Add component style
        $document->addStyleSheet('/administrator/components/com_itpmeta/assets/css/style.css', 'text/css', null, array('id' => 'ITPMainStyleSheet'));
        
        $viewType = $document->getType();
        
        // Set add and edit task parameters
        switch($this->getTask()){
            case 'add':
                {
                    JRequest::setVar('hidemainmenu', 1);
                    JRequest::setVar('layout', 'form');
                
                }
                break;
            case 'edit':
                {
                    JRequest::setVar('hidemainmenu', 1);
                    JRequest::setVar('layout', 'form');
                
                }
                break;
        
        }
        
        // Get layout value
        $viewLayout = JRequest::getVar('layout', 'default');
        // Get view value
        $viewName = JRequest::getVar('view', $this->_name);
        
        // Get view
        $view = $this->getView($viewName, $viewType, "View");
        
        // Get model
        $model = $this->getModel($viewName, "Model");
        if(!JError::isError($model)){ // Set model to view
            $view->setModel($model, true);
        }
        
        // Set layout into view 
        $view->setLayout($viewLayout);
        
        try{
            // Display view
            $view->display();
        }catch(Exception $e){
            
            $itpSecurity = new ItpSecurity($e);
            $itpSecurity->AlertMe();
            
            JError::raiseError(500, JText::_('ITP_ERROR_SYSTEM'));
            jexit(JText::_('ITP_ERROR_SYSTEM'));
        
        }
    
    }
    
    /**
     * Store data into DB
     *
     */
    public function save(){
        
        // Check token
        if(!JRequest::getVar(JUtility::getToken(), false, 'POST')){
            JError::raiseError(500, JText::_('ITP_ERROR_REQUEST_FORBIDDEN'));
        }
        
        $msg = "";
        $task = $this->getTask();
        
        // Gets the data from the form
        $id      = JRequest::getInt('id');
        $content = JRequest::getVar('content', "", "post", "string", JREQUEST_ALLOWRAW);
        $url     = JRequest::getVar('url', "", "post", "string");
        $published = JRequest::getInt('published', 0);
        
        try{
            
            $model = & $this->getModel($this->_name, "Model");
            
            $id = $model->store($url, $content, $published, $id);
            
            $msg = JText::_('ITP_URLS_SAVED');
        
        }catch(ItpUserException $e){
            
            $msg = "";
            JError::raiseWarning(500, $e->getMessage());
        
        }catch(Exception $e){
            
            $itpSecurity = new ItpSecurity($e);
            $itpSecurity->AlertMe();
            
            JError::raiseError(500, JText::_('ITP_ERROR_SYSTEM'));
            jexit(JText::_('ITP_ERROR_SYSTEM'));
        
        }
        
        if(strcmp($task, "apply") == 0){
            $this->defaultLink .= "&task=edit&cid[0]=" . (int)$id;
        }
        
        $this->setRedirect($this->defaultLink, $msg);
    
    }
    
    /**
     * Remove items
     *
     */
    public function remove(){
        
        // Checks token
        if(!JRequest::getVar(JUtility::getToken(), false, 'POST')){
            JError::raiseError(500, JText::_('ITP_ERROR_REQUEST_FORBIDDEN'));
        }
        
        $msg = "";
        
        $cids = JRequest::getVar('cid', array(), 'post', 'array');
        JArrayHelper::toInteger($cids);
        
        try{
            
            // Gets the model
            $model = & $this->getModel($this->_name, "Model");
            $model->delete($cids);
            
            $msg = JText::_('ITP_URLS_DELETED');
        
        }catch(ItpUserException $e){
            
            $msg = "";
            JError::raiseWarning(404, $e->getMessage());
        
        }catch(Exception $e){
            
            $itpSecurity = new ItpSecurity($e);
            $itpSecurity->AlertMe();
            
            JError::raiseError(500, JText::_('ITP_ERROR_SYSTEM'));
            jexit(JText::_('ITP_ERROR_SYSTEM'));
        
        }
        
        $this->setRedirect($this->defaultLink, $msg);
    
    }
    
    public function loadEditForm(){
        
        // Gets the data from the form
        $id      = JRequest::getInt('id');
        
        try{
            
            $model = & $this->getModel($this->_name, "Model");
            $tag   = $model->getTag($id);
            
        }catch(Exception $e){
            
            $itpSecurity = new ItpSecurity($e);
            $itpSecurity->AlertMe();
            
            JError::raiseError(500, JText::_('ITP_ERROR_SYSTEM'));
            jexit(JText::_('ITP_ERROR_SYSTEM'));
        
        }
        
        $html='
        <form action="index.php" method="post" enctype="multipart/form-data" name="adminForm">
          <p><textarea name="content" id="itpm-edit-content" style="width:100%;height:100px; border: thin solid gray;">' . $tag->content . '</textarea></p>
    <p>
      <input type="hidden" name="option" value="com_itpmeta" />
      <input type="hidden" name="controller" value="urls" />
      <input type="hidden" name="task" value="saveTag" />
      <input type="hidden" name="view" value="urls" />
      <input type="hidden" name="format" value="raw" />
      <input type="hidden" name="id" value="' . $id . '" />
      ' . JHTML::_( "form.token" ) . ' 
    </p>
    <p style="width:100%;text-align:center;"><input type="submit" value="' . JText::_("Submit") . '" style="width:100px;" /></p>
    </form>
        ';
        echo $html;
    }
    
    /**
     * Loads a content
     */
    public function loadTag(){
        
        $tagId  = JRequest::getVar('tag_id');
        
        try{
            
            $model  = &$this->getModel($this->_name, "Model");
            $tag   = $model->getTag($tagId);
            
        }catch(Exception $e){
            
            $itpSecurity = new ItpSecurity($e);
            $itpSecurity->AlertMe();
            
            JError::raiseError(500, JText::_('ITP_ERROR_SYSTEM'));
            jexit(JText::_('ITP_ERROR_SYSTEM'));
        
        }
        
        echo htmlspecialchars(JString::substr($tag->content,0,128));
    }
    
    /**
     * Remove a tag
     */
    public function removeTag(){
        
        $tagId  = JRequest::getVar('tag_id');
        
        try{
            
            $model  = &$this->getModel($this->_name, "Model");
            $model->deleteTag($tagId);
            
        }catch(Exception $e){
            
            $itpSecurity = new ItpSecurity($e);
            $itpSecurity->AlertMe();
            
            JError::raiseError(500, JText::_('ITP_ERROR_SYSTEM'));
            jexit(JText::_('ITP_ERROR_SYSTEM'));
        
        }
        
        ItpResponse::sendAjaxMsg(JText::_("ITP_TAGS_DELETED"),1);
    }
    
    
    /**
     * Store edited tag
     *
     */
    public function saveTag(){
        
        // Check token
        if(!JRequest::getVar(JUtility::getToken(), false, 'POST')){
            JError::raiseError(500, JText::_('ITP_ERROR_REQUEST_FORBIDDEN'));
        }
        
        $msg = "";
        
        // Tag ID
        $id      = JRequest::getInt('id');
        $content = JRequest::getVar('content', "", "post", "string", JREQUEST_ALLOWRAW);
        
        try{
            
            $model   = & $this->getModel($this->_name, "Model");
            $model->storeTag($id, $content);
            
            $msg     = JText::_("ITP_TAGS_SAVED");
            
        }catch(ItpUserException $e){
            
            $msg = "";
            JError::raiseWarning(500, $e->getMessage());
        
        }catch(Exception $e){
            
            $itpSecurity = new ItpSecurity($e);
            $itpSecurity->AlertMe();
            
            JError::raiseError(500, JText::_('ITP_ERROR_SYSTEM'));
            jexit(JText::_('ITP_ERROR_SYSTEM'));
        
        }
    
        echo $msg;
    }
    
/**
     * Publish items
     *
     */
    public function publish() {
        
        // Checks the token
        if(!JRequest::getVar(JUtility::getToken(), false, 'POST'))  {
            JError::raiseError( 500, JText::_( 'ITP_ERROR_REQUEST_FORBIDDEN' ));
        }
        
        $cids = JRequest::getVar( 'cid' );
        JArrayHelper::toInteger($cids);

        try {
            
            // Gets the model
            $model =& $this->getModel( $this->_name, "Model" );
            $model->publish($cids, 1);
            
            $msg = JText::_( 'ITP_URLS_UPDATED' );

        } catch ( ItpUserException $e ) {
            
            $msg = "";
            JError::raiseWarning( 404, $e->getMessage() );
            
        } catch ( Exception $e ) {
            
            $itpSecurity = new ItpSecurity( $e );
            $itpSecurity->AlertMe();
           
            JError::raiseError( 500, JText::_( 'ITP_ERROR_SYSTEM' ) );
            jexit(JText::_( 'ITP_ERROR_SYSTEM' ));
            
        }
        
        $this->setRedirect( $this->defaultLink, $msg );
    }

    /**
     * Unpublish items
     *
     */
    public function unpublish() {
        
        // Checks the token
        if(!JRequest::getVar(JUtility::getToken(), false, 'POST'))  {
            JError::raiseError(500, JText::_( 'ITP_ERROR_REQUEST_FORBIDDEN' ));
        }
        
        $cids = JRequest::getVar( 'cid', array());
        JArrayHelper::toInteger($cids);
        
        try {
            
            // Gets the model
            $model =& $this->getModel( $this->_name, "Model" );
            $model->publish($cids, 0);
            
            $msg = JText::_( 'ITP_URLS_UPDATED' );

        } catch ( ItpUserException $e ) {
            
            $msg = "";
            JError::raiseWarning( 404, $e->getMessage() );
            
        } catch ( Exception $e ) {
            
            $itpSecurity = new ItpSecurity( $e );
            $itpSecurity->AlertMe();
           
            JError::raiseError( 500, JText::_( 'ITP_ERROR_SYSTEM' ) );
            jexit(JText::_( 'ITP_ERROR_SYSTEM' ));
            
        }
        
        $this->setRedirect( $this->defaultLink, $msg );
        
    }
    
    /**
     * Cancel operations
     *
     */
    public function cancel(){
        
        $msg = "";
        $this->setRedirect($this->defaultLink, $msg);
    
    }

}