<?php
/**
 * @package      ITPrism Components
 * @subpackage   ITPMeta
 * @author       Todor Iliev
 * @copyright    Copyright (C) 2010 Todor Iliev <todor@itprism.com>. All rights reserved.
 * @license      http://www.gnu.org/copyleft/gpl.html GNU/GPL
 * ITPMeta is free software. This version may have been modified pursuant
 * to the GNU General Public License, and as distributed it includes or
 * is derivative of works licensed under the GNU General Public License or
 * other free or open source software licenses.
 */

// no direct access
defined('_JEXEC') or die('Restricted access');

jimport('joomla.application.component.model');

class ModelUrls extends JModel {
    
    /**
     * Data array
     *
     * @var array
     */
    private $data = null;
    
    /**
     * Data total
     *
     * @var integer
     */
    private $total = null;
    
    /**
     * Pagination object
     *
     * @var object
     */
    private $pagination = null;
    
    /**
     * The Constructor of the Users model
     */
    public function __construct(){
        
        parent::__construct();
        
        global $mainframe, $option;
        
        // Get the pagination request variables
        $limit = $mainframe->getUserStateFromRequest('global.list.limit', 'limit', $mainframe->getCfg('list_limit'), 'int');
        $limitstart = $mainframe->getUserStateFromRequest($option . "." . $this->getName() . ".limitstart", 'limitstart', 0, 'int');
        
        // In case limit has been changed, adjust limitstart accordingly
        $limitstart = ($limit != 0 ? (floor($limitstart / $limit) * $limit) : 0);
        
        $this->setState('limit', $limit);
        $this->setState('limitstart', $limitstart);
    
    }
    
    /**
     * Method to get data
     *
     * @since 1.5
     */
    public function getData(){
        
        $query = $this->buildQuery();
        $this->data = $this->_getList($query, $this->getState('limitstart'), $this->getState('limit'));
        
        return $this->data;
    }
    
    /**
     * Method to get a pagination object of the records
     *
     * @access public
     * @return integer
     */
    public function getPagination(){
        
        // Lets load the content if it doesn't already exist
        if(empty($this->pagination)){
            jimport('joomla.html.pagination');
            $this->pagination = new JPagination($this->getTotal(), $this->getState('limitstart'), $this->getState('limit'));
        }
        
        return $this->pagination;
    }
    
    /**
     * Method to get the total number of the records
     *
     * @access public
     * @return integer
     */
    public function getTotal(){
        // Lets load the content if it doesn't already exist
        if(empty($this->total)){
            $query = $this->buildQuery();
            
            $this->total = $this->_getListCount($query);
        }
        
        return $this->total;
    }
    
    /**
     * Building query
     *
     * @return string
     */
    public function buildQuery(){
        
        // Get the WHERE and ORDER BY clauses for the query
        $where = $this->buildContentWhere();
        $orderby = $this->buildContentOrderBy();
        
        $tableUrls = $this->_db->nameQuote("#__itpm_urls");
        
        $query = "
		  SELECT  
		      *
          FROM 
              $tableUrls";
        
        $query .= $where;
        $query .= $orderby;
        
        return $query;
    }
    
    /**
     * Build 'order' part of query
     *
     * @return string
     */
    private function buildContentOrderBy(){
        
        global $mainframe, $option;
        $orderby = "";
        
        // Order
        $filterOrder = $mainframe->getUserStateFromRequest($option . "." . $this->getName() . ".filter_order", 'filter_order', 'url', 'cmd');
        $filterOrderDir = $mainframe->getUserStateFromRequest($option . "." . $this->getName() . ".filter_order_Dir", 'filter_order_Dir', 'asc', 'word');
        
        if($filterOrder and $filterOrderDir){
            $orderby = ' ORDER BY ' . $filterOrder . ' ' . $filterOrderDir;
        }
        
        return $orderby;
    }
    
    /**
     * Build 'where' part of query
     *
     * @return string
     */
    private function buildContentWhere(){
        
        global $mainframe, $option;
        
        $where = array();
        
        $filterSearch = $mainframe->getUserStateFromRequest($option . "." . $this->getName() . ".filter_search", 'filter_search');
        
        if(!empty($filterSearch)){
            
            $tableUrls = $this->_db->nameQuote("#__itpm_urls");
            $columnUrl = $this->_db->nameQuote("url");
            // prepare search
            $filterSearch = $this->_db->getEscaped($filterSearch, true);
            $filterSearch = $this->_db->Quote('%' . $filterSearch . '%', false);
            
            $where[] = " $tableUrls.$columnUrl LIKE $filterSearch";
        
        }
        
        $where = (count($where)) ? ' WHERE ' . implode(' AND ', $where) : '';
        
        return $where;
    }
    
    /**
     * Save url and tag into the DB
     * 
     * @param $url         A web page URL 
     * @param $content     A tag in HTML code style
     * @param $published   It is state of the tag - published or not published
     * @param $id          The ID of the tag
     * 
     * @return     ID of the item
     */
    public function store($url, $content = "", $published = 0, $urlId = null){
        
        if(!$url){
            throw new ItpUserException(JText::_('ITP_ERROR_INVALID_URL'), 404);
        }
        
        // Adds new url
        if(!$urlId) {
            
            if(!empty($content)){
                /* URL */
                $tableUrls       = $this->_db->nameQuote("#__itpm_urls");
                $columnUrl       = $this->_db->nameQuote("url");
                $columnPublished = $this->_db->nameQuote("published");
                
                $query = "
                    INSERT INTO
                        $tableUrls
                    SET
                        $columnUrl=" . $this->_db->Quote($url) . ",
                        $columnPublished = " .(int)$published;
                
                $this->_db->setQuery($query);
                
                if(!$this->_db->query()){
                    throw new ItpException($this->_db->getErrorMsg(), 500);
                }
                        
                $urlId = $this->_db->insertid();
            }
            
        } else { 
            
            /* Publish or unpublish the url */
            $row            = $this->getTable();
            $row->load($urlId);
            $row->published = $published; 
            $row->url       = $url;
            $row->store();
                
        }
        
        /* Adds a new tag */
        if(!empty($content)){
            $tableTags      = $this->_db->nameQuote("#__itpm_tags");
            $columnContent  = $this->_db->nameQuote("content");
            $columnUrlId    = $this->_db->nameQuote("url_id");
            
            $query = "
                INSERT INTO
                    $tableTags
                SET
                    $columnContent=" . $this->_db->Quote($content) . ",
                    $columnUrlId= " .(int)$urlId;
            
            $this->_db->setQuery($query);
            
            if(!$this->_db->query()){
                throw new ItpException($this->_db->getErrorMsg(), 500);
            }
        }
        
        return $urlId;
    
    }
    
    /**
     * Delete records from table "urls"
     *
     * @param array $cids
     * @exception ItpException
     */
    public function delete($cids){
        
        if(!$cids){
            throw new ItpException(JText::_('ITP_ERROR_INVALID_ITEMS'), 404);
        }
        
        $tableTags    = $this->_db->nameQuote('#__itpm_tags');
        $columnUrlId  = $this->_db->nameQuote('url_id');
        
        // Delete tags 
        $query = "
            DELETE  
            FROM 
                 $tableTags 
            WHERE   
                 $columnUrlId IN ( " . implode(',', $cids) . " )";
        
        $this->_db->setQuery($query);
        
        if(!$this->_db->query()){
            throw new ItpException($this->_db->getErrorMsg(), 500);
        }
        
        
        // Delete URLS
        $tableUrls = $this->_db->nameQuote('#__itpm_urls');
        $columnId  = $this->_db->nameQuote('id');
         
        $query = "
			DELETE  
			FROM 
			     $tableUrls 
			WHERE   
			     $columnId IN ( " . implode(',', $cids) . " )";
        
        $this->_db->setQuery($query);
        
        if(!$this->_db->query()){
            throw new ItpException($this->_db->getErrorMsg(), 500);
        }
    
    }
    
    /**
     * Delete records from table "tags"
     *
     * @param array $tagId
     * @exception ItpException
     */
    public function deleteTag($tagId){
        
        if(!$tagId){
            throw new ItpException(JText::_('ITP_ERROR_INVALID_ITEMS'), 404);
        }
        
        $tableTags = $this->_db->nameQuote('#__itpm_tags');
        $columnId = $this->_db->nameQuote('id');
        
        // Delete records 
        $query = "
            DELETE  
            FROM 
                 $tableTags 
            WHERE   
                 $columnId = " . (int)$tagId;
        
        $this->_db->setQuery($query);
        
        if(!$this->_db->query()){
            throw new ItpException($this->_db->getErrorMsg(), 500);
        }
    
    }
    
    /**
     * Get tags from DB
     *
     * @param       integer $urlId
     * @exception   ItpException
     * @return      array A list with tag objects
     */
    public function getTags($urlId){
        
        if(!$urlId){
            throw new ItpException(JText::_('ITP_ERROR_INVALID_ITEMS'), 404);
        }
        
        $tableTags   = $this->_db->nameQuote('#__itpm_tags');
        $columnUrlId = $this->_db->nameQuote('url_id');
        
        // Delete categories 
        $query = "
            SELECT 
                *  
            FROM 
                 $tableTags 
            WHERE   
                 $columnUrlId=" . (int)$urlId;
        
        $this->_db->setQuery($query);
        $result = $this->_db->loadObjectList();
        
        if ($this->_db->getErrorNum() != 0) {
            throw new ItpException($this->_db->getErrorMsg(), 500);
        }
        
        return $result;
    
    }
    
    /**
     * Gets a tag
     *
     * @param       array $tagId
     * @exception   ItpException
     */
    public function getTag($tagId){
        
        if(!$tagId){
            throw new ItpException(JText::_('ITP_ERROR_INVALID_ITEMS'), 404);
        }
        
        $tableTags  = $this->_db->nameQuote('#__itpm_tags');
        $columnId   = $this->_db->nameQuote('id');
        
        // Delete categories 
        $query = "
            SELECT 
                *  
            FROM 
                 $tableTags 
            WHERE   
                 $columnId=" . (int)$tagId;
        
        $this->_db->setQuery($query);
        $result = $this->_db->loadObject();
        
        if ($this->_db->getErrorNum() != 0) {
            throw new ItpException($this->_db->getErrorMsg(), 500);
        }
        
        return $result;
    
    }
    
    /**
     * Save tag into the DB
     * 
     * @param $tagId       Tag ID
     * @param $content     A tag in HTML code style
     * 
     */
    public function storeTag($tagId, $content){
        
        if(!empty($tagId) AND !empty($content)) {

            $row = JTable::getInstance('Tags', 'Table');
            
            $row->load($tagId);
            if(!$row->url_id){
                throw new ItpException(JText::_('ITP_ERROR_INVALID_ITEMS'), 404);
            }
            
            $row->set("content", $content);
            $row->store();
        }
        
    
    }
    
    /**
     * Method to (un)publish item
     *
     * @access  public
     * @return  boolean True on success
     * @since   1.5
     * @exception ItpUserException
     * @exception ItpException
     */
    public function publish( $cids, $publish = 1 ) {
        
        if ( !$cids ) {
            throw new ItpUserException( JText::_( 'ITP_ERROR_INVALID_ITEMS_SELECTED' ), 404 );
        }
        
        $tableUrls        = $this->_db->nameQuote('#__itpm_urls');
        $columnPublished  = $this->_db->nameQuote('published');
        $columnId         = $this->_db->nameQuote('id');
        
        $query = "
          UPDATE  
              $tableUrls
          SET     
              $columnPublished = ".(int) $publish . " 
          WHERE   
              $columnId IN ( ".implode( ",", $cids )." )";

        $this->_db->setQuery( $query );
        
        if( !$this->_db->query() ) {
            throw new ItpException( $this->_db->getErrorMsg() , 500 );
        }

    }

}